pub struct EventSubscription {
pub event_matcher: Option<EventMatcher>,
pub query: Option<Query>,
pub operation: i32,
}Expand description
Below message is used to communicate between dest-relay and src-relay; and src-relay and src-driver.
Fields
event_matcher: Option<EventMatcher>query: Option<Query>operation: i32Implementations
Sourceimpl EventSubscription
impl EventSubscription
Sourcepub fn operation(&self) -> EventSubOperation
pub fn operation(&self) -> EventSubOperation
Returns the enum value of operation, or the default if the field is set to an invalid enum value.
Sourcepub fn set_operation(&mut self, value: EventSubOperation)
pub fn set_operation(&mut self, value: EventSubOperation)
Sets operation to the provided enum value.