#[repr(i32)]pub enum Status {
PendingAck = 0,
Pending = 1,
Error = 2,
Completed = 3,
EventReceived = 4,
EventWritten = 5,
EventWriteError = 6,
Deleted = 7,
}Variants
PendingAck = 0
pending ACK from remote relay
Pending = 1
Received ACK, waiting for data to be sent from remote relay
Error = 2
View is not there, received error from remote relay
Completed = 3
Data Sharing completed Successfully
EventReceived = 4
View is there and event is received from remote relay
EventWritten = 5
Driver Successfully wrote the view to ledger
EventWriteError = 6
View is there but driver failed to write
Deleted = 7
Once network fetches this request state, mark it delete for cleanup later on
Implementations
Sourceimpl Status
impl Status
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.