pub struct Meta {
pub protocol: i32,
pub timestamp: String,
pub proof_type: String,
pub serialization_format: String,
}Expand description
Metadata for a View
Fields
protocol: i32Underlying distributed ledger protocol.
timestamp: StringWhat notion of time? If the observer and network are synchronizing on a global clock there won’t be a need to distinguish between static and dynamic views.
proof_type: StringNotorization, SPV, ZKP, etc. Possibly enum
serialization_format: StringThe data field’s serialization format (e.g. JSON, XML, Protobuf)
Implementations