pub struct View {
pub meta: Option<Meta>,
pub data: Vec<u8>,
}Fields
meta: Option<Meta>data: Vec<u8>Represents the data playload of this view. The representation of Fabric, Corda etc will be captured elsewhere. For some protocols, like Bitcoin, the structure of an SPV proof is well known.